@@ -1,9 +1,13 @@
 import requests
+from scrapeanything.database.repository import Repository
+from scrapeanything.utils.config import Config
 from scrapeanything.utils.service import Service
 
 class TelegramBot(Service):
 
-    def __init__(self) -> None:
+    def __init__(self, config: Config=None, repository: Repository=None) -> None:
+        super().__init__(config, repository)
+
         self.TOKEN = self.config.get(section='NOTIFIERS', key='TELEGRAM_CHATID')
         self.CHAT_ID = self.config.get(section='NOTIFIERS', key='TELEGRAM_TOKEN')
         # self.TOKEN = '6023559959:AAHYuMGqqqAtO4I5D3DSX5THtVLGaYgsuTI'
