@@ -202,8 +202,8 @@ class Scraper:
     def hover(self, path: str, element: any=None, is_error: bool=True) -> None:
         self.on_hover(path=path, element=element, is_error=is_error) 
 
-    def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
-        return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
+    def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0, is_error: bool=False):
+        return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout, is_error=is_error)
 
     def click(self, path: str, element: any=None, timeout: int=0, pos: int=0, is_error: bool=True) -> any:
         return self.on_click(path=path, element=element, timeout=timeout, pos=pos, is_error=is_error)
